==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/barrel/dialogs_es.lua <==

dialogId("bar-v-videt0", "font_big", "Somebody from Greenpeace should see this.")
dialogStr("Alguien de Greenpeace debería de ver esto.")


dialogId("bar-m-videt1", "font_small", "Somebody from Three Miles Island should see this.")
dialogStr("Alguien de las islas cercanas debería de ver esto.")


dialogId("bar-v-co", "font_big", "What are we supposed to do with it?")
dialogStr("¿Que se supone que hagamos con eso?")


dialogId("bar-m-pobit", "font_small", "We have to exterminate all of them. Such abominations have no right to breath the same air... er, water, as we do.")
dialogStr("Tenemos que exterminarlos a todos. Esas abominaciones no tiene el derecho a respirar el mismo aire... eh, agua, que nosotros.")


dialogId("bar-v-priciny", "font_big", "I think we have to eliminate the cause and not the results.")
dialogStr("Creo que tenemos que eliminar la causa y no los resultados.")


dialogId("bar-m-no", "font_small", "Well, you may be right.")
dialogStr("Bueno, podrías estar en lo correcto.")


dialogId("bar-v-sud", "font_big", "And the cause is doubtless this giant barrel. We have to get it out somehow.")
dialogStr("Y la causa es sin duda este barril gigante. Tenemos que sacarlo de alguna forma.")


dialogId("bar-m-panb", "font_small", "Yes. Let`s get to work. We can drop it on the Mr. B.`s front yard afterwards.")
dialogStr("Si. Vamos a trabajar. Podemos tirarlo en el patio delantero del Sr. B. más tarde.")


dialogId("bar-m-rada", "font_small", "I think I am growing to like them.")
dialogStr("Creo que me empiezan a gustar.")


dialogId("bar-v-kdyby0", "font_big", "If only they wouldn`t stand in our way so much.")
dialogStr("Si sólo ellos no se pusieran en nuestro camino tantas veces.")


dialogId("bar-v-kdyby1", "font_big", "If only they were where we need them.")
dialogStr("Si sólo ellos estuvieran donde los necesitáramos.")


dialogId("bar-v-sbirka", "font_big", "Such a lovely collection of monstrosities. I`ll be sorry to leave.")
dialogStr("Que adorable colección de monstruocidades. Me sentiré mal cuando me valla.")


dialogId("bar-m-dost0", "font_small", "That won`t happen any time soon.")
dialogStr("Eso no deberá de ocurrir tan pronto.")


dialogId("bar-m-dost1", "font_small", "You are going to have plenty of time to enjoy them.")
dialogStr("Vas a tener todo el tiempo para disfrutarlos.")


dialogId("bar-v-lih", "font_big", "If we take them with us and store them in alcohol, we could found ourselves a freak show.")
dialogStr("Si los llevamos con nosotros y los guardamos en alcohol, podríamos tener un show del horror.")


dialogId("bar-m-fdto", "font_small", "And FDTO isn`t enough for you?")
dialogStr("¿Y FDTO no es suficiente para ti?")


dialogId("bar-x-vypr", "font_white", "I can hear everything!")
dialogStr("¡Puedo escucharlo todo!")


dialogId("bar-m-promin", "font_small", "Sorry, boss. I didn`t mean to offend.")
dialogStr("Disculpa, jefe. No fué mi intención ofender.")


dialogId("bar-m-mutanti", "font_small", "You know, I finally realized that even mutants have a soul.")
dialogStr("Tu sabes, finalmente me di cuenta que incluso los mutantes tienen alma.")


dialogId("bar-v-ufouni", "font_big", "Maybe even UFOs can have a soul.")
dialogStr("Quizás incluso OVNIs puedan tener alma.")


dialogId("bar-m-zmeni", "font_small", "I think that this level is going to change us forever.")
dialogStr("Creo que este nivel nos va a cambiar para siempre.")


dialogId("bar-m-noha", "font_small", "That foot is not only repulsive but also shameless. Just look at it.")
dialogStr("Ese pié no sólamente es repulsivo, sinó que también vergonzoso. Sólo míralo.")


dialogId("bar-v-pld", "font_big", "Look at that pld. It looks the same and still it grows more and more repulsive.")
dialogStr("Mira esa cosa. Parece idéntica y crece todavía más y más repulsiva.")


dialogId("bar-m-pudy", "font_small", "But even it harbors some motherly instincts. Look how it cares about the little one.")
dialogStr("Pero aún abriga algunos instintos maternales. Mira cómo cuida del pequeño.")


dialogId("bar-v-traverza", "font_big", "Yes. It almost killed it with iron beam.")
dialogStr("Si. Casi lo mató con una viga de hierro.")


dialogId("bar-m-rybka", "font_small", "This fish looks familiar to me.")
dialogStr("Este pez me parece familiar.")


dialogId("bar-v-fotka", "font_big", "Maybe it was in that photo from the power plant.")
dialogStr("Quizás fué en esa foto de la planta eléctrica.")


dialogId("bar-v-krab", "font_big", "The poor crab. So many pincers and no head. Although... maybe he is better off than us.")
dialogStr("El pobre cangrejo. Tantas pinzas y sin cabeza. Aunque... quizás él esté mejor que nosotros.")


dialogId("bar-m-kachna", "font_small", "No man is alone with a little yellow duck. Not even fish.")
dialogStr("Ningún hombre está solo con un pequeño pato amarillo. Tampoco un pez.")


dialogId("bar-m-barel", "font_small", "This time, our goal is to push out the barrel with that filth.")
dialogStr("Ahora, nuestra meta es empujar el barril con esa inmundicia.")


dialogId("bar-v-genofond", "font_big", "But we have to leave all those creatures here. They must not harm the genepool of the healthy population.")
dialogStr("Pero tenemos que dejar todas esas criaturas aquí. Ellas no deben dañar el ecosistema de la población sana.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/barrel/dialogs_es.lua <==

dialogId("bar-v-videt0", "font_big", "Somebody from Greenpeace should see this.")
dialogStr("Alguien de Greenpeace debería de ver esto.")


dialogId("bar-m-videt1", "font_small", "Somebody from Three Miles Island should see this.")
dialogStr("Alguien de las islas cercanas debería de ver esto.")


dialogId("bar-v-co", "font_big", "What are we supposed to do with it?")
dialogStr("¿Que se supone que hagamos con eso?")


dialogId("bar-m-pobit", "font_small", "We have to exterminate all of them. Such abominations have no right to breath the same air... er, water, as we do.")
dialogStr("Tenemos que exterminarlos a todos. Esas abominaciones no tiene el derecho a respirar el mismo aire... eh, agua, que nosotros.")


dialogId("bar-v-priciny", "font_big", "I think we have to eliminate the cause and not the results.")
dialogStr("Creo que tenemos que eliminar la causa y no los resultados.")


dialogId("bar-m-no", "font_small", "Well, you may be right.")
dialogStr("Bueno, podrías estar en lo correcto.")


dialogId("bar-v-sud", "font_big", "And the cause is doubtless this giant barrel. We have to get it out somehow.")
dialogStr("Y la causa es sin duda este barril gigante. Tenemos que sacarlo de alguna forma.")


dialogId("bar-m-panb", "font_small", "Yes. Let’s get to work. We can drop it on the Mr. B.’s front yard afterwards.")
dialogStr("Si. Vamos a trabajar. Podemos tirarlo en el patio delantero del Sr. B. más tarde.")


dialogId("bar-m-rada", "font_small", "I think I am growing to like them.")
dialogStr("Creo que me empiezan a gustar.")


dialogId("bar-v-kdyby0", "font_big", "If only they wouldn’t stand in our way so much.")
dialogStr("Si sólo ellos no se pusieran en nuestro camino tantas veces.")


dialogId("bar-v-kdyby1", "font_big", "If only they were where we need them.")
dialogStr("Si sólo ellos estuvieran donde los necesitáramos.")


dialogId("bar-v-sbirka", "font_big", "Such a lovely collection of monstrosities. I’ll be sorry to leave.")
dialogStr("Que adorable colección de monstruocidades. Me sentiré mal cuando me valla.")


dialogId("bar-m-dost0", "font_small", "That won’t happen any time soon.")
dialogStr("Eso no deberá de ocurrir tan pronto.")


dialogId("bar-m-dost1", "font_small", "You are going to have plenty of time to enjoy them.")
dialogStr("Vas a tener todo el tiempo para disfrutarlos.")


dialogId("bar-v-lih", "font_big", "If we take them with us and store them in alcohol, we could found ourselves a freak show.")
dialogStr("Si los llevamos con nosotros y los guardamos en alcohol, podríamos tener un show del horror.")


dialogId("bar-m-fdto", "font_small", "And FDTO isn’t enough for you?")
dialogStr("¿Y FDTO no es suficiente para ti?")


dialogId("bar-x-vypr", "font_white", "I can hear everything!")
dialogStr("¡Puedo escucharlo todo!")


dialogId("bar-m-promin", "font_small", "Sorry, boss. I didn’t mean to offend.")
dialogStr("Disculpa, jefe. No fué mi intención ofender.")


dialogId("bar-m-mutanti", "font_small", "You know, I finally realized that even mutants have a soul.")
dialogStr("Tu sabes, finalmente me di cuenta que incluso los mutantes tienen alma.")


dialogId("bar-v-ufouni", "font_big", "Maybe even UFOs can have a soul.")
dialogStr("Quizás incluso OVNIs puedan tener alma.")


dialogId("bar-m-zmeni", "font_small", "I think that this level is going to change us forever.")
dialogStr("Creo que este nivel nos va a cambiar para siempre.")


dialogId("bar-m-noha", "font_small", "That foot is not only repulsive but also shameless. Just look at it.")
dialogStr("Ese pié no sólamente es repulsivo, sinó que también vergonzoso. Sólo míralo.")


dialogId("bar-v-pld", "font_big", "Look at that pld. It looks the same and still it grows more and more repulsive.")
dialogStr("Mira esa cosa. Parece idéntica y crece todavía más y más repulsiva.")


dialogId("bar-m-pudy", "font_small", "But even it harbors some motherly instincts. Look how it cares about the little one.")
dialogStr("Pero aún abriga algunos instintos maternales. Mira cómo cuida del pequeño.")


dialogId("bar-v-traverza", "font_big", "Yes. It almost killed it with iron beam.")
dialogStr("Si. Casi lo mató con una viga de hierro.")


dialogId("bar-m-rybka", "font_small", "This fish looks familiar to me.")
dialogStr("Este pez me parece familiar.")


dialogId("bar-v-fotka", "font_big", "Maybe it was in that photo from the power plant.")
dialogStr("Quizás fué en esa foto de la planta eléctrica.")


dialogId("bar-v-krab", "font_big", "The poor crab. So many pincers and no head. Although... maybe he is better off than us.")
dialogStr("El pobre cangrejo. Tantas pinzas y sin cabeza. Aunque... quizás él esté mejor que nosotros.")


dialogId("bar-m-kachna", "font_small", "No man is alone with a little yellow duck. Not even fish.")
dialogStr("Ningún hombre está solo con un pequeño pato amarillo. Tampoco un pez.")


dialogId("bar-m-barel", "font_small", "This time, our goal is to push out the barrel with that filth.")
dialogStr("Ahora, nuestra meta es empujar el barril con esa inmundicia.")


dialogId("bar-v-genofond", "font_big", "But we have to leave all those creatures here. They must not harm the genepool of the healthy population.")
dialogStr("Pero tenemos que dejar todas esas criaturas aquí. Ellas no deben dañar el ecosistema de la población sana.")
